[Scummvm-cvs-logs] CVS: scummvm/scumm actor.cpp,1.391,1.392 saveload.h,1.72,1.73

kirben kirben at users.sourceforge.net
Sun Nov 27 15:49:02 CET 2005


Update of /cvsroot/scummvm/scummvm/scumm
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv25466/scumm

Modified Files:
	actor.cpp saveload.h 
Log Message:

Actor sounds need to be saved as uint16 for HE games, fixes bug #1367798.


Index: saveload.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/saveload.h,v
retrieving revision 1.72
retrieving revision 1.73
diff -u -d -r1.72 -r1.73
--- saveload.h	2 Nov 2005 21:47:43 -0000	1.72
+++ saveload.h	27 Nov 2005 23:48:14 -0000	1.73
@@ -45,7 +45,7 @@
  * only saves/loads those which are valid for the version of the savegame
  * which is being loaded/saved currently.
  */
-#define CURRENT_VER 61
+#define CURRENT_VER 62
 
 /**
  * An auxillary macro, used to specify savegame versions. We use this instead





More information about the Scummvm-git-logs mailing list
Index: actor.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/actor.cpp,v
retrieving revision 1.391
retrieving revision 1.392
diff -u -d -r1.391 -r1.392
--- actor.cpp	5 Nov 2005 00:11:49 -0000	1.391
+++ actor.cpp	27 Nov 2005 23:48:14 -0000	1.392
@@ -2150,9 +2150,10 @@
 		MKLINE(Actor, _scaley, sleByte, VER(8)),
 		MKLINE(Actor, _charset, sleByte, VER(8)),
 
 		// Actor sound grew from 8 to 32 bytes
 		MKARRAY_OLD(Actor, _sound[0], sleByte, 8, VER(8), VER(36)),
-		MKARRAY(Actor, _sound[0], sleByte, 32, VER(37)),
+		MKARRAY_OLD(Actor, _sound[0], sleByte, 32, VER(37), VER(61)),
+		MKARRAY(Actor, _sound[0], sleUint16, 32, VER(62)),
 
 		// Actor animVariable grew from 8 to 27
 		MKARRAY_OLD(Actor, _animVariable[0], sleUint16, 8, VER(8), VER(40)),
@@ -2150,9 +2150,10 @@
 		MKLINE(Actor, _charset, sleByte, VER(8)),
 
-		// Actor sound grew from 8 to 32 bytes
+		// Actor sound grew from 8 to 32 bytes and switched to uint16 in HE games
 		MKARRAY_OLD(Actor, _sound[0], sleByte, 8, VER(8), VER(36)),
